==> jboss-eap-src-5.1.2.zip: jboss-eap-5.1-src/jboss-as/hornetq-int/src/main/java/org/jboss/as/integration/hornetq/recovery/AS5RecoveryRegistry.java <==
/*
* JBoss, Home of Professional Open Source.
* Copyright 2010, Red Hat, Inc., and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.as.integration.hornetq.recovery;

import org.jboss.tm.XAResourceRecoveryRegistry;
import org.hornetq.jms.server.recovery.HornetQResourceRecovery;
import org.hornetq.jms.server.recovery.RecoveryRegistry;
import org.hornetq.jms.server.recovery.XARecoveryConfig;


/**
 * @author <a href="mailto:andy.taylor@jboss.org">Andy Taylor</a>
 *         9/19/11
 */
public class AS5RecoveryRegistry implements RecoveryRegistry
{
   static volatile XAResourceRecoveryRegistry registry;


   public AS5RecoveryRegistry()
   {
      super();
   }

   public AS5RecoveryRegistry(XAResourceRecoveryRegistry registry)
   {
      AS5RecoveryRegistry.registry = registry;
   }

   public void register(HornetQResourceRecovery resourceRecovery)
   {
      registry.addXAResourceRecovery(resourceRecovery);
   }

   public void unRegister(HornetQResourceRecovery resourceRecovery)
   {
      registry.removeXAResourceRecovery(resourceRecovery);
   }

}

==> jboss-eap-src-5.2.0.zip: jboss-eap-5.2-src/jboss-as/hornetq-int/src/main/java/org/jboss/as/integration/hornetq/recovery/AS5RecoveryRegistry.java <==
/*
* JBoss, Home of Professional Open Source.
* Copyright 2010, Red Hat, Inc., and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.as.integration.hornetq.recovery;

import org.hornetq.jms.server.recovery.HornetQRegistryBase;
import org.jboss.logging.Logger;
import org.jboss.tm.XAResourceRecoveryRegistry;


/**
 * @author <a href="mailto:andy.taylor@jboss.org">Andy Taylor</a>
 * @author Clebert Suconic
 *         9/19/11
 */
public class AS5RecoveryRegistry extends HornetQRegistryBase
{
   private static final Logger log = Logger
         .getLogger(AS5RecoveryRegistry.class);
   static volatile XAResourceRecoveryRegistry registry;


   public AS5RecoveryRegistry()
   {
      super();
   }

   public AS5RecoveryRegistry(XAResourceRecoveryRegistry registry)
   {
      AS5RecoveryRegistry.registry = registry;
   }
   
   public XAResourceRecoveryRegistry getTMRegistry()
   {
      return registry;
   }
   

}
